@@ -546,6 +546,82 @@ class HdpWs:
         return self.__get_complex_resource([ResourceType.CATALOG], query, date_range)
 
 
+    def get_spase_collection(
+            self,
+            query: Dict
+        ) -> Dict:
+        """
+        Gets the specified SPASE Collection documents from HDP.
+
+        Parameters
+        ----------
+        query
+            Dictionary containing query parameters and values.  For
+            example,<pre>
+            query = { 
+                'ResourceID': 'spase://NASA/Collection/IRIS_AIA',
+                'MemberID': 'spase://NASA/NumericalData/SDO/AIA/PT10S',
+                'Description': 'IRIS AND SDO and AIA'
+            }</pre>
+
+        Returns
+        -------
+            Dictionary containing a 'Result' key with a value of an
+            ElementTree representation of the results as described by
+            <https://heliophysicsdata.gsfc.nasa.gov/WebServices/hdpspase.xsd>
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        return self.__get_complex_resource([ResourceType.COLLECTION], query)
+
+
+    def get_spase_document(
+            self,
+            query: Dict
+        ) -> Dict:
+        """
+        Gets the specified SPASE Document documents from HDP.
+
+        Parameters
+        ----------
+        query
+            Dictionary containing query parameters and values.  For
+            example,<pre>
+            query = { 
+                'ResourceID': 'spase://SMWG/Document/HPDE/Policy/HP_DataPolicy_v1.2',
+                'DOI': '10.21978/P83P78',
+                'Description': '"Program Data Management Plan"'
+            }</pre>
+
+        Returns
+        -------
+            Dictionary containing a 'Result' key with a value of an
+            ElementTree representation of the results as described by
+            <https://heliophysicsdata.gsfc.nasa.gov/WebServices/hdpspase.xsd>
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        return self.__get_complex_resource([ResourceType.DOCUMENT], query)
+
+
     def __get_simple_resource(
             self,
             resource: str,
